==> fess-fess_tags_fess-6.0.0-r1348.tar.gz: fess-fess_tags_fess-6.0.0-r1348/fess-6.0.0/src/main/java/jp/sf/fess/helper/CrawlingConfigHelper.java <==
/*
 * Copyright 2009-2012 the Fess Project and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package jp.sf.fess.helper;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

import jp.sf.fess.db.exentity.CrawlingConfig;

public class CrawlingConfigHelper implements Serializable {

    private static final long serialVersionUID = 1L;

    protected static final Map<String, CrawlingConfig> CRAWLING_CONFIG_MAP = new HashMap<String, CrawlingConfig>();

    public void setCrawlingConfig(final String sessionId,
            final CrawlingConfig crawlingConfig) {
        if (crawlingConfig != null) {
            CRAWLING_CONFIG_MAP.put(sessionId, crawlingConfig);
        } else {
            CRAWLING_CONFIG_MAP.remove(sessionId);
        }
    }

    public CrawlingConfig getCrawlingConfig(final String sessionId) {
        return CRAWLING_CONFIG_MAP.get(sessionId);
    }

    public void init() {
        CRAWLING_CONFIG_MAP.clear();
    }
}

==> fess-fess_tags_fess-7.0.1-r1373.tar.gz: fess-fess_tags_fess-7.0.1-r1373/fess-7.0.1/src/main/java/jp/sf/fess/helper/CrawlingConfigHelper.java <==
/*
 * Copyright 2009-2012 the Fess Project and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package jp.sf.fess.helper;

import java.io.Serializable;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import jp.sf.fess.db.exentity.CrawlingConfig;

public class CrawlingConfigHelper implements Serializable {

    private static final long serialVersionUID = 1L;

    protected final Map<String, CrawlingConfig> crawlingConfigMap = new ConcurrentHashMap<String, CrawlingConfig>();

    protected int count = 1;

    public synchronized String store(final String sessionId,
            final CrawlingConfig crawlingConfig) {
        final String sid = sessionId + "-" + count;
        crawlingConfigMap.put(sid, crawlingConfig);
        count++;
        return sid;
    }

    public void remove(final String sessionId) {
        crawlingConfigMap.remove(sessionId);
    }

    public CrawlingConfig get(final String sessionId) {
        return crawlingConfigMap.get(sessionId);
    }

}
